@@ -1,15 +1,8 @@
 use strict;
 use warnings;
-package App::WIoZ;
-BEGIN {
-  $App::WIoZ::VERSION = '0.003';
-}
-
-1;
-
 package App::WIoZ::Point;
-BEGIN {
-  $App::WIoZ::Point::VERSION = '0.003';
+{
+  $App::WIoZ::Point::VERSION = '0.004';
 }
 use Moose;
 
